@@ -1,6 +1,6 @@
 require 'strategies/special_characters_helper'
 
-describe 'the match_prev_cmd strategy' do
+describe 'the `match_prev_cmd` strategy' do
   let(:options) { ['ZSH_AUTOSUGGEST_STRATEGY=match_prev_cmd'] }
 
   it 'suggests the last matching history entry after the previous command' do
